==> wiki3_5_3.zip: wiki3_5_3/plugin/core/Install.pm <==
############################################################
#
# FreeStyleWikiδŪʵǽ󶡤ޤ
#
############################################################
package plugin::core::Install;
use strict;

sub install {
	my $wiki  = shift;
	my $login = $wiki->get_login_info();
	
	$wiki->add_menu("FrontPage",$wiki->config('script_name')."?page=FrontPage",999);
	
	if($wiki->config('accept_edit')!=0 || defined($login)){
		$wiki->add_menu("",$wiki->config('script_name')."?action=NEW",998);
	}
	
	$wiki->add_menu("Խ"  ,"",997);
	$wiki->add_menu("ʬ"  ,"",996);
	$wiki->add_menu(""  ,$wiki->config('script_name')."?action=LIST",995);
	$wiki->add_menu("إ",$wiki->config('script_name')."?page=Help",100);
	
	$wiki->add_handler("","plugin::core::ShowPage");
	$wiki->add_handler("NEW","plugin::core::NewPage");
	$wiki->add_handler("LIST","plugin::core::ListPage");
	
	$wiki->add_handler("EDIT","plugin::core::EditPage");
	$wiki->add_hook("show","plugin::core::EditPage");
	
	$wiki->add_handler("DIFF","plugin::core::Diff");
	$wiki->add_hook("show","plugin::core::Diff");
	
	$wiki->add_paragraph_plugin("include" ,"plugin::core::Include" ,"WIKI");
	$wiki->add_inline_plugin("edit","plugin::core::Edit","HTML");

	$wiki->add_hook("save_after","plugin::core::SendMail");
	$wiki->add_hook("delete"    ,"plugin::core::SendMail");
	
	$wiki->add_editform_plugin("plugin::core::Template",100);
	$wiki->add_editform_plugin("plugin::core::EditHelper",0);

	$wiki->add_menu("","",700);
	$wiki->add_handler("SOURCE","plugin::core::Source");
	$wiki->add_hook("show","plugin::core::Source");
	
	$wiki->add_hook("save_after","plugin::core::KeywordCache");
	$wiki->add_hook("delete"    ,"plugin::core::KeywordCache");

	$wiki->add_paragraph_plugin("format_help","plugin::core::FormatHelp","WIKI");
	$wiki->add_paragraph_plugin("paragraph","plugin::core::Paragraph","WIKI");
	
	# FarmطΥץ饰򥤥󥹥ȡ
	$wiki->add_admin_menu("WikiFarm",$wiki->config('script_name')."?action=ADMINFARM",950,
						  "WikiFarmư˴ؤԤޤ");
	$wiki->add_admin_handler("ADMINFARM","plugin::core::AdminFarmHandler");
	
	if($wiki->farm_is_enable()){
		$wiki->add_paragraph_plugin("wiki_list","plugin::core::WikiList","HTML");
		$wiki->add_handler("CREATE_WIKI","plugin::core::CreateWikiHandler");
		$wiki->add_handler("REMOVE_WIKI","plugin::core::RemoveWikiHandler");
		$wiki->add_menu("Farm",$wiki->config('script_name')."?action=CREATE_WIKI",993);
	}
}

1;

==> wiki3_5_6dev1.zip: wiki3_5_6dev1/plugin/core/Install.pm <==
############################################################
#
# FreeStyleWikiδŪʵǽ󶡤ޤ
#
############################################################
package plugin::core::Install;
use strict;

sub install {
	my $wiki  = shift;
	my $login = $wiki->get_login_info();
	
	$wiki->add_menu("ȥå",$wiki->config('script_name')."?page=".&Util::url_encode($wiki->config("frontpage")),999);
	
	if($wiki->config('accept_edit')!=0 || defined($login)){
		$wiki->add_menu("",$wiki->config('script_name')."?action=NEW",998);
	}
	
	$wiki->add_menu("Խ"  ,"",997);
	$wiki->add_menu("ʬ"  ,"",996);
	$wiki->add_menu(""  ,$wiki->config('script_name')."?action=LIST",995);
	$wiki->add_menu("إ",$wiki->config('script_name')."?page=Help",100);
	
	$wiki->add_handler("","plugin::core::ShowPage");
	$wiki->add_handler("NEW","plugin::core::NewPage");
	$wiki->add_handler("LIST","plugin::core::ListPage");
	
	$wiki->add_handler("EDIT","plugin::core::EditPage");
	$wiki->add_hook("show","plugin::core::EditPage");
	
	$wiki->add_handler("DIFF","plugin::core::Diff");
	$wiki->add_hook("show","plugin::core::Diff");
	
	$wiki->add_paragraph_plugin("include" ,"plugin::core::Include" ,"WIKI");
	$wiki->add_inline_plugin("edit","plugin::core::Edit","HTML");

	$wiki->add_hook("save_after","plugin::core::SendMail");
	$wiki->add_hook("delete"    ,"plugin::core::SendMail");
	
	$wiki->add_editform_plugin("plugin::core::Template",100);
	$wiki->add_editform_plugin("plugin::core::EditHelper",0);

	$wiki->add_menu("","",700);
	$wiki->add_handler("SOURCE","plugin::core::Source");
	$wiki->add_hook("show","plugin::core::Source");
	
	$wiki->add_hook("save_after","plugin::core::KeywordCache");
	$wiki->add_hook("delete"    ,"plugin::core::KeywordCache");

	$wiki->add_paragraph_plugin("format_help","plugin::core::FormatHelp","WIKI");
	$wiki->add_paragraph_plugin("paragraph","plugin::core::Paragraph","WIKI");
	
	# FarmطΥץ饰򥤥󥹥ȡ
	$wiki->add_admin_menu("WikiFarm",$wiki->config('script_name')."?action=ADMINFARM",950,
						  "WikiFarmư˴ؤԤޤ");
	$wiki->add_admin_handler("ADMINFARM","plugin::core::AdminFarmHandler");
	
	if($wiki->farm_is_enable()){
		$wiki->add_paragraph_plugin("wiki_list","plugin::core::WikiList","HTML");
		$wiki->add_handler("CREATE_WIKI","plugin::core::CreateWikiHandler");
		$wiki->add_handler("REMOVE_WIKI","plugin::core::RemoveWikiHandler");
		$wiki->add_menu("Farm",$wiki->config('script_name')."?action=CREATE_WIKI",993);
	}
}

1;
